@@ -78,6 +78,7 @@ import org.videolan.vlc.gui.browser.ExtensionBrowser;
 import org.videolan.vlc.gui.browser.FileBrowserFragment;
 import org.videolan.vlc.gui.browser.MediaBrowserFragment;
 import org.videolan.vlc.gui.browser.NetworkBrowserFragment;
+import org.videolan.vlc.gui.browser.StorageBrowserFragment;
 import org.videolan.vlc.gui.helpers.UiTools;
 import org.videolan.vlc.gui.network.MRLPanelFragment;
 import org.videolan.vlc.gui.preferences.PreferencesActivity;
@@ -496,19 +497,17 @@ public class MainActivity extends AudioPlayerContainerActivity implements Filter
         if (menu == null)
             return false;
         Fragment current = getSupportFragmentManager().findFragmentById(R.id.fragment_placeholder);
-        MenuItem item;
+        MenuItem item = menu.findItem(R.id.ml_menu_sortby);
+        if (item == null)
+            return false;
         // Disable the sort option if we can't use it on the current fragment.
-        if (current == null || !(current instanceof ISortable)) {
-            item = menu.findItem(R.id.ml_menu_sortby);
-            if (item == null)
-                return false;
+        if (current == null || !(current instanceof ISortable)
+                || (current instanceof BaseBrowserFragment && !((BaseBrowserFragment)current).isSortEnabled())) {
             item.setEnabled(false);
             item.setVisible(false);
         } else {
             ISortable sortable = (ISortable) current;
             item = menu.findItem(R.id.ml_menu_sortby);
-            if (item == null)
-                return false;
             item.setEnabled(true);
             item.setVisible(true);
             item = menu.findItem(R.id.ml_menu_sortby_name);
@@ -516,16 +515,21 @@ public class MainActivity extends AudioPlayerContainerActivity implements Filter
                 item.setTitle(R.string.sortby_name_desc);
             else
                 item.setTitle(R.string.sortby_name);
-            item = menu.findItem(R.id.ml_menu_sortby_length);
-            if (sortable.sortDirection(VideoListAdapter.SORT_BY_LENGTH) == 1)
-                item.setTitle(R.string.sortby_length_desc);
-            else
-                item.setTitle(R.string.sortby_length);
-            item = menu.findItem(R.id.ml_menu_sortby_date);
-            if (sortable.sortDirection(VideoListAdapter.SORT_BY_DATE) == 1)
-                item.setTitle(R.string.sortby_date_desc);
-            else
-                item.setTitle(R.string.sortby_date);
+            if (current instanceof NetworkBrowserFragment) {
+                menu.findItem(R.id.ml_menu_sortby_length).setVisible(false);
+                menu.findItem(R.id.ml_menu_sortby_date).setVisible(false);
+            } else {
+                item = menu.findItem(R.id.ml_menu_sortby_length);
+                if (sortable.sortDirection(VideoListAdapter.SORT_BY_LENGTH) == 1)
+                    item.setTitle(R.string.sortby_length_desc);
+                else
+                    item.setTitle(R.string.sortby_length);
+                item = menu.findItem(R.id.ml_menu_sortby_date);
+                if (sortable.sortDirection(VideoListAdapter.SORT_BY_DATE) == 1)
+                    item.setTitle(R.string.sortby_date_desc);
+                else
+                    item.setTitle(R.string.sortby_date);
+            }
         }
 
         if (current instanceof NetworkBrowserFragment &&
@@ -646,6 +650,11 @@ public class MainActivity extends AudioPlayerContainerActivity implements Filter
                     finish();
                     startActivity(intent);
                     break;
+                case PreferencesActivity.RESULT_UPDATE_SEEN_MEDIA:
+                    for (Fragment fragment : getSupportFragmentManager().getFragments())
+                        if (fragment instanceof VideoGridFragment)
+                            ((VideoGridFragment) fragment).updateSeenMediaMarker();
+                    break;
             }
         } else if (requestCode == ACTIVITY_RESULT_OPEN && resultCode == RESULT_OK){
             MediaUtils.openUri(this, data.getData());
