@@ -56,6 +56,7 @@ import org.videolan.vlc.gui.view.SwipeRefreshLayout;
 import org.videolan.vlc.media.MediaUtils;
 import org.videolan.vlc.util.AndroidDevices;
 import org.videolan.vlc.util.FileUtils;
+import org.videolan.vlc.util.Util;
 
 import java.util.ArrayList;
 import java.util.Arrays;
@@ -271,15 +272,16 @@ public class AudioAlbumsSongsFragment extends BaseAudioBrowser implements SwipeR
         VLCApplication.runBackground(new Runnable() {
             @Override
             public void run() {
-                final Album[] albums;
-                if (mItem.getItemType() == MediaLibraryItem.TYPE_ARTIST)
-                    albums = ((Artist) mItem).getAlbums(mMediaLibrary);
+                final ArrayList<? extends MediaLibraryItem> albums;
+                if (mItem.getItemType() == MediaLibraryItem.TYPE_ARTIST) {
+                    albums = Util.arrayToArrayList(((Artist) mItem).getAlbums(mMediaLibrary));
+                }
                 else if (mItem.getItemType() == MediaLibraryItem.TYPE_GENRE)
-                    albums = ((Genre) mItem).getAlbums(mMediaLibrary);
+                    albums = Util.arrayToArrayList(((Genre) mItem).getAlbums(mMediaLibrary));
                 else
                     return;
                 final LinkedList<MediaLibraryItem> songs = new LinkedList<>();
-                for (Album album : albums) {
+                for (Album album : (ArrayList<Album>) albums) {
                     String title = album.getTitle();
                     if (TextUtils.isEmpty(title))
                         title = getString(R.string.unknown_album);
@@ -290,7 +292,7 @@ public class AudioAlbumsSongsFragment extends BaseAudioBrowser implements SwipeR
                     @Override
                     public void run() {
                         mAlbumsAdapter.update(albums);
-                        mSongsAdapter.update(songs.toArray(new MediaLibraryItem[songs.size()]));
+                        mSongsAdapter.update(new ArrayList<>(songs));
                         mFastScroller.setRecyclerView(mLists[mViewPager.getCurrentItem()]);
                         mSwipeRefreshLayout.setRefreshing(false);
                     }
