@@ -123,11 +123,11 @@ public class PlaylistAdapter extends BaseQueuedAdapter<ArrayList<MediaWrapper>,
     }
 
     @MainThread
-    protected void internalUpdate(final ArrayList<MediaWrapper> newList) {
+    protected void internalUpdate(final ArrayList<MediaWrapper> newList, final boolean detectMoves) {
         VLCApplication.runBackground(new Runnable() {
             @Override
             public void run() {
-                final DiffUtil.DiffResult result = DiffUtil.calculateDiff(new MediaItemDiffCallback(mDataSet, newList), false);
+                final DiffUtil.DiffResult result = DiffUtil.calculateDiff(new MediaItemDiffCallback(mDataSet, newList), detectMoves);
                 VLCApplication.runOnMainThread(new Runnable() {
                     @Override
                     public void run() {
@@ -283,10 +283,8 @@ public class PlaylistAdapter extends BaseQueuedAdapter<ArrayList<MediaWrapper>,
             FilterResults results = new FilterResults();
             ArrayList<MediaWrapper> list = new ArrayList<>();
             String title, location, artist, album, albumArtist, genre;
-            MediaWrapper media;
             mediaLoop:
-            for (int i = 0 ; i < mOriginalDataSet.size() ; ++i) {
-                media = mOriginalDataSet.get(i);
+            for (MediaWrapper media : mOriginalDataSet) {
                 title = MediaUtils.getMediaTitle(media);
                 location = media.getLocation();
                 artist = MediaUtils.getMediaArtist(VLCApplication.getAppContext(), media).toLowerCase();
