@@ -59,6 +59,10 @@ public class FileBrowserFragment<T extends BaseBrowserAdapter> extends BaseBrows
         ROOT = AndroidDevices.EXTERNAL_PUBLIC_DIRECTORY;
     }
 
+    public boolean isSortEnabled() {
+        return !mRoot;
+    }
+
     @Override
     public void onCreate(Bundle bundle) {
         super.onCreate(bundle);
