@@ -23,11 +23,10 @@
 
 package org.videolan.vlc.gui.browser;
 
-import android.support.v7.widget.RecyclerView;
-import android.view.View;
+import org.videolan.medialibrary.media.MediaLibraryItem;
+import org.videolan.medialibrary.media.MediaWrapper;
 
-import org.videolan.libvlc.Media;
-import org.videolan.vlc.media.MediaWrapper;
+import static org.videolan.medialibrary.media.MediaLibraryItem.TYPE_MEDIA;
 
 public class FilePickerAdapter extends BaseBrowserAdapter {
 
@@ -35,38 +34,24 @@ public class FilePickerAdapter extends BaseBrowserAdapter {
         super(fragment);
     }
 
-    public void addItem(Object media, boolean notify, boolean top){
-        MediaWrapper mediaWrapper;
-        if (media instanceof MediaWrapper)
-            mediaWrapper = (MediaWrapper) media;
-        else
-            mediaWrapper = new MediaWrapper((Media)media);
-        if (filter(mediaWrapper))
-            super.addItem(mediaWrapper, notify, top);
+    public void addItem(MediaLibraryItem media, boolean top){
+        if (media.getItemType() != TYPE_MEDIA)
+            return;
+        if (filter((MediaWrapper) media))
+            super.addItem(media, top);
     }
 
-    public void onBindViewHolder(final RecyclerView.ViewHolder holder, int position) {
+    public void onBindViewHolder(final ViewHolder holder, int position) {
         final MediaViewHolder vh = (MediaViewHolder) holder;
         final MediaWrapper media = (MediaWrapper) getItem(position);
-        vh.binding.setMedia(media);
+        vh.binding.setItem(media);
         vh.binding.setHasContextMenu(false);
-        vh.binding.setType(TYPE_MEDIA);
         vh.binding.setProtocol(null);
-        vh.binding.executePendingBindings();
-
-        vh.binding.dviIcon.setBackgroundResource(getIconResId(media));
+        vh.binding.setCover(getIcon(media));
     }
 
     //TODO update with different filter types in other cases than subtitles selection
     private boolean filter(MediaWrapper mediaWrapper) {
         return mediaWrapper.getType() == MediaWrapper.TYPE_DIR || mediaWrapper.getType() == MediaWrapper.TYPE_SUBTITLE;
     }
-
-    protected void openMediaFromView(MediaViewHolder holder, View v) {
-        final MediaWrapper media = (MediaWrapper) getItem(holder.getAdapterPosition());
-        if (media.getType() == MediaWrapper.TYPE_DIR)
-            fragment.browse(media, holder.getAdapterPosition(), true);
-        else
-            ((FilePickerFragment)fragment).pickFile(media);
-    }
 }
