@@ -125,12 +125,6 @@ public abstract class SortedBrowserFragment extends BrowseFragment implements Br
         VLCApplication.storeData(CURRENT_BROWSER_LIST, mVideosList);
     }
 
-    @Override
-    public void onStop() {
-        super.onStop();
-        mBackgroundManager.release();
-    }
-
     @Override
     public void onSaveInstanceState(Bundle outState) {
         super.onSaveInstanceState(outState);
